@@ -2,11 +2,10 @@ import json
 import requests
 
 
-def upload(filename="", file="", custom_headers={}):
+def upload(filename="", file=""):
 
     headers = {
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36",
-        "Referer": "pyscord-storage 0.1.3",
     }
 
     # upload file from URL
@@ -22,7 +21,7 @@ def upload(filename="", file="", custom_headers={}):
         response = requests.request(
             "POST",
             url,
-            headers=headers if custom_headers == {} else custom_headers,
+            headers=headers,
             data=payload,
         )
 
